==> cpes6-project-1.0.12.tgz: package/src/dom.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/8/2
 * To change this template use File | Settings | File Templates.
 */

import cp from './els';

let tempParent = document.createElement('div'), $ = cp.el;
cp.extend(cp, {
    matches: function (element, selector) {
        if (!element || element.nodeType !== 1) return false;
        let matchesSelector = element.webkitMatchesSelector || element.mozMatchesSelector ||
            element.oMatchesSelector || element.matchesSelector;
        if (matchesSelector) return matchesSelector.call(element, selector);
        let match, parent = element.parentNode, temp = !parent;
        if (temp) (parent = tempParent).appendChild(element);
        match = ~cp.ge(parent, selector).indexOf(element);
        temp && tempParent.removeChild(element);
        return match
    }
})
cp.extend(cp.fn, {
    closest: function (selector, context) {
        let node = this[0], collection = false;
        if (typeof selector == 'object') collection = cp.el(selector);
        while (node && !(collection ? collection.indexOf(node) >= 0 : cp.matches(node, selector))) {
            node = node !== context && !cp.isDocument(node) && node.parentNode;
        }
        return cp.el(node)
    },
    contains (parent, node) {
        return parent !== node && parent.contains(node)
    },
    is: function (selector) {
        return this.length > 0 && cp.matches(this[0], selector)
    },
    remove: function () {
        return this.each(function () {
            if (this.parentNode != null)
                this.parentNode.removeChild(this)
        })
    },
    children: function () {
        if (0 in this) {
            return children(this[0]);
        }
        return this;
    },
    parent: function () {
        if (0 in this) {
            return $(this[0].parentNode);
        }
        return this;
    },
    find: function (selector) {
        var result, $this = this
        if (!selector) result = $();
        else if (this.length == 1) result = $(cp.ge(this[0], selector))
        else result = this.map(function () {
                return cp.ge(this, selector)
            })
        return result
    }
});

==> cpes6-project-1.1.1.tgz: package/src/dom.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/8/2
 * To change this template use File | Settings | File Templates.
 */

import cp from './els';

let tempParent = document.createElement('div'), $ = cp.el;

function children(element) {
    return 'children' in element ?
        [].slice.call(element.children) :
        $.map(element.childNodes, function (node) {
            if (node.nodeType == 1) return node
        })
}
cp.extend(cp, {
    matches: function (element, selector) {
        if (!element || element.nodeType !== 1) return false;
        let matchesSelector = element.webkitMatchesSelector || element.mozMatchesSelector ||
            element.oMatchesSelector || element.matchesSelector;
        if (matchesSelector) return matchesSelector.call(element, selector);
        let match, parent = element.parentNode, temp = !parent;
        if (temp) (parent = tempParent).appendChild(element);
        match = ~cp.ge(parent, selector).indexOf(element);
        temp && tempParent.removeChild(element);
        return match
    }
})
cp.extend(cp.fn, {
    closest: function (selector, context) {
        let node = this[0], collection = false;
        if (typeof selector == 'object') collection = cp.el(selector);
        while (node && !(collection ? collection.indexOf(node) >= 0 : cp.matches(node, selector))) {
            node = node !== context && !cp.isDocument(node) && node.parentNode;
        }
        return cp.el(node)
    },
    contains (parent, node) {
        return parent !== node && parent.contains(node)
    },
    is: function (selector) {
        return this.length > 0 && cp.matches(this[0], selector)
    },
    remove: function () {
        return this.each(function () {
            if (this.parentNode != null)
                this.parentNode.removeChild(this)
        })
    },
    children: function () {
        if (0 in this) return children(this[0]);
        return this;
    },
    parent: function () {
        if (0 in this) {
            return $(this[0].parentNode);
        }
        return this;
    },
    find: function (selector) {
        var result;
        if (!selector) result = $();
        else if (this.length == 1) result = $(cp.ge(this[0], selector));
        else result = this.map(function () {
                return cp.ge(this, selector)
            })
        return result
    }
});
